import fedmsg
import fedmsg.encoding

from . import utils, config
from . import JobTrigger

ITEM_TYPE = 'koji_build'

class KojiJobTrigger(JobTrigger):
    topic = "org.fedoraproject.prod.buildsys.tag"
    jsonify = False
    config_key = 'taskotron.kojijobtrigger.enabled'

    def __init__(self, *args, **kw):
        super(KojiJobTrigger, self).__init__(*args, **kw)

    def consume(self, message):
        usable_message = fedmsg.encoding.loads(message.body)

        tag = usable_message['msg']['tag']
        release = usable_message['msg']['release']

        # we look only for pending builds
        if not tag.endswith('pending'):
            return

        # do not schledule jobs for blacklisted releases
        if release.endswith(tuple(config.blacklist_releases)):
            return

        name = usable_message['msg']['name']
        version = usable_message['msg']['version']
        buildid = usable_message['msg']['build_id']

        envr = "%s-%s-%s" % (name, version, release)

        arches = utils.get_arches(buildid=buildid)

        self.trigger_tasks(envr, ITEM_TYPE, config.koji_tasks, arches)
